pub enum IbvOperation {
Write,
WriteWithImm,
Read,
Recv,
}Expand description
Enum representing the common RDMA operations.
This provides a more ergonomic interface to the underlying ibv_wr_opcode types. RDMA operations allow for direct memory access between two machines without involving the CPU of the target machine.
Variants
Write- Represents an RDMA write operation where data is written from the local memory to a remote memory region.Read- Represents an RDMA read operation where data is read from a remote memory region into the local memory.
Variants