pub struct IbvMemoryRegionView {
pub id: usize,
pub virtual_addr: usize,
pub rdma_addr: usize,
pub size: usize,
pub lkey: u32,
pub rkey: u32,
}Expand description
Represents a view of a memory region that can be registered with an RDMA device.
This is a ‘view’ of a registered Memory Region, allowing multiple views into a single large MR registration. This is commonly used with PyTorch’s caching allocator, which reserves large memory blocks and provides different data pointers into that space.
Example
PyTorch Caching Allocator creates a 16GB segment at virtual address 0x01000000.
The underlying Memory Region registers 16GB but at RDMA address 0x0.
To access virtual address 0x01100000, we return a view at RDMA address 0x100000.
Safety
The caller must ensure the memory remains valid and is not freed, moved, or overwritten while RDMA operations are in progress.
Fields
id: usizevirtual_addr: usizeVirtual address in the process address space. This is the pointer/address as seen by the local process.
rdma_addr: usizeMemory address assigned after Memory Region (MR) registration. This is the address may be offset a base MR addr.
size: usizelkey: u32rkey: u32Implementations